/****************************************************************************
** Meta object code from reading C++ file 'UIConsoleEventHandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/runtime/UIConsoleEventHandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIConsoleEventHandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21UIConsoleEventHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto UIConsoleEventHandler::qt_create_metaobjectdata<qt_meta_tag_ZN21UIConsoleEventHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIConsoleEventHandler",
        "sigMousePointerShapeChange",
        "",
        "UIMousePointerShapeData",
        "shapeData",
        "sigMouseCapabilityChange",
        "fSupportsAbsolute",
        "fSupportsRelative",
        "fSupportsTouchScreen",
        "fSupportsTouchPad",
        "fNeedsHostCursor",
        "sigCursorPositionChange",
        "fContainsData",
        "uX",
        "uY",
        "sigKeyboardLedsChange",
        "fNumLock",
        "fCapsLock",
        "fScrollLock",
        "sigStateChange",
        "KMachineState",
        "state",
        "sigAdditionsChange",
        "sigNetworkAdapterChange",
        "CNetworkAdapter",
        "adapter",
        "sigStorageDeviceChange",
        "CMediumAttachment",
        "attachment",
        "fRemoved",
        "fSilent",
        "sigMediumChange",
        "sigVRDEChange",
        "sigRecordingChange",
        "sigUSBControllerChange",
        "sigUSBDeviceStateChange",
        "CUSBDevice",
        "device",
        "fAttached",
        "CVirtualBoxErrorInfo",
        "error",
        "sigSharedFolderChange",
        "sigCPUExecutionCapChange",
        "sigGuestMonitorChange",
        "KGuestMonitorChangedEventType",
        "type",
        "uScreenId",
        "QRect",
        "screenGeo",
        "sigRuntimeError",
        "fFatal",
        "strErrorId",
        "strMessage",
        "sigAudioAdapterChange",
        "sigClipboardModeChange",
        "KClipboardMode",
        "enmMode",
        "sigClipboardError",
        "strMsg",
        "sigDnDModeChange",
        "KDnDMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigMousePointerShapeChange'
        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigMouseCapabilityChange'
        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 }, { QMetaType::Bool, 7 }, { QMetaType::Bool, 8 }, { QMetaType::Bool, 9 },
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'sigCursorPositionChange'
        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 }, { QMetaType::ULong, 13 }, { QMetaType::ULong, 14 },
        }}),
        // Signal 'sigKeyboardLedsChange'
        QtMocHelpers::SignalData<void(bool, bool, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Signal 'sigStateChange'
        QtMocHelpers::SignalData<void(KMachineState)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'sigAdditionsChange'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigNetworkAdapterChange'
        QtMocHelpers::SignalData<void(CNetworkAdapter)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Signal 'sigStorageDeviceChange'
        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 }, { QMetaType::Bool, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Signal 'sigMediumChange'
        QtMocHelpers::SignalData<void(CMediumAttachment)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'sigVRDEChange'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRecordingChange'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigUSBControllerChange'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigUSBDeviceStateChange'
        QtMocHelpers::SignalData<void(CUSBDevice, bool, CVirtualBoxErrorInfo)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::Bool, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Signal 'sigSharedFolderChange'
        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCPUExecutionCapChange'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigGuestMonitorChange'
        QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { QMetaType::ULong, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Signal 'sigRuntimeError'
        QtMocHelpers::SignalData<void(bool, QString, QString)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 50 }, { QMetaType::QString, 51 }, { QMetaType::QString, 52 },
        }}),
        // Signal 'sigAudioAdapterChange'
        QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigClipboardModeChange'
        QtMocHelpers::SignalData<void(KClipboardMode)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Signal 'sigClipboardError'
        QtMocHelpers::SignalData<void(const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 58 },
        }}),
        // Signal 'sigDnDModeChange'
        QtMocHelpers::SignalData<void(KDnDMode)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 60, 56 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIConsoleEventHandler, qt_meta_tag_ZN21UIConsoleEventHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIConsoleEventHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UIConsoleEventHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UIConsoleEventHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21UIConsoleEventHandlerE_t>.metaTypes,
    nullptr
} };

void UIConsoleEventHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIConsoleEventHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
        case 1: _t->sigMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 2: _t->sigCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
        case 3: _t->sigKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->sigStateChange((*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[1]))); break;
        case 5: _t->sigAdditionsChange(); break;
        case 6: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
        case 7: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
        case 9: _t->sigVRDEChange(); break;
        case 10: _t->sigRecordingChange(); break;
        case 11: _t->sigUSBControllerChange(); break;
        case 12: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
        case 13: _t->sigSharedFolderChange(); break;
        case 14: _t->sigCPUExecutionCapChange(); break;
        case 15: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
        case 16: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->sigAudioAdapterChange(); break;
        case 18: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
        case 19: _t->sigClipboardError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMachineState >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CNetworkAdapter >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMediumAttachment >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMediumAttachment >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CUSBDevice >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CVirtualBoxErrorInfo >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGuestMonitorChangedEventType >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KClipboardMode >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDnDMode >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(const UIMousePointerShapeData & )>(_a, &UIConsoleEventHandler::sigMousePointerShapeChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(bool , bool , bool , bool , bool )>(_a, &UIConsoleEventHandler::sigMouseCapabilityChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(bool , unsigned long , unsigned long )>(_a, &UIConsoleEventHandler::sigCursorPositionChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(bool , bool , bool )>(_a, &UIConsoleEventHandler::sigKeyboardLedsChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(KMachineState )>(_a, &UIConsoleEventHandler::sigStateChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigAdditionsChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(CNetworkAdapter )>(_a, &UIConsoleEventHandler::sigNetworkAdapterChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(CMediumAttachment , bool , bool )>(_a, &UIConsoleEventHandler::sigStorageDeviceChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(CMediumAttachment )>(_a, &UIConsoleEventHandler::sigMediumChange, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigVRDEChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigRecordingChange, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigUSBControllerChange, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(CUSBDevice , bool , CVirtualBoxErrorInfo )>(_a, &UIConsoleEventHandler::sigUSBDeviceStateChange, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigSharedFolderChange, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigCPUExecutionCapChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(KGuestMonitorChangedEventType , ulong , QRect )>(_a, &UIConsoleEventHandler::sigGuestMonitorChange, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(bool , QString , QString )>(_a, &UIConsoleEventHandler::sigRuntimeError, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)()>(_a, &UIConsoleEventHandler::sigAudioAdapterChange, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(KClipboardMode )>(_a, &UIConsoleEventHandler::sigClipboardModeChange, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(const QString & )>(_a, &UIConsoleEventHandler::sigClipboardError, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIConsoleEventHandler::*)(KDnDMode )>(_a, &UIConsoleEventHandler::sigDnDModeChange, 20))
            return;
    }
}

const QMetaObject *UIConsoleEventHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIConsoleEventHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UIConsoleEventHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UIConsoleEventHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void UIConsoleEventHandler::sigMousePointerShapeChange(const UIMousePointerShapeData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UIConsoleEventHandler::sigMouseCapabilityChange(bool _t1, bool _t2, bool _t3, bool _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 2
void UIConsoleEventHandler::sigCursorPositionChange(bool _t1, unsigned long _t2, unsigned long _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void UIConsoleEventHandler::sigKeyboardLedsChange(bool _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void UIConsoleEventHandler::sigStateChange(KMachineState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UIConsoleEventHandler::sigAdditionsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void UIConsoleEventHandler::sigNetworkAdapterChange(CNetworkAdapter _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void UIConsoleEventHandler::sigStorageDeviceChange(CMediumAttachment _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void UIConsoleEventHandler::sigMediumChange(CMediumAttachment _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void UIConsoleEventHandler::sigVRDEChange()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void UIConsoleEventHandler::sigRecordingChange()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void UIConsoleEventHandler::sigUSBControllerChange()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void UIConsoleEventHandler::sigUSBDeviceStateChange(CUSBDevice _t1, bool _t2, CVirtualBoxErrorInfo _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3);
}

// SIGNAL 13
void UIConsoleEventHandler::sigSharedFolderChange()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void UIConsoleEventHandler::sigCPUExecutionCapChange()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void UIConsoleEventHandler::sigGuestMonitorChange(KGuestMonitorChangedEventType _t1, ulong _t2, QRect _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void UIConsoleEventHandler::sigRuntimeError(bool _t1, QString _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void UIConsoleEventHandler::sigAudioAdapterChange()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void UIConsoleEventHandler::sigClipboardModeChange(KClipboardMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void UIConsoleEventHandler::sigClipboardError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void UIConsoleEventHandler::sigDnDModeChange(KDnDMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}
QT_WARNING_POP
